{% load i18n l10n %}
{% load humanize %}
<!DOCTYPE html PUBLIC "-//W3C//DTD HTML 4.01//EN" "http://www.w3.org/TR/html4/strict.dtd">

<html>
<head>
	<meta http-equiv="Content-Type" content="text/html; charset=utf-8">
</head>
    <script type="text/javascript">
        var pdfInfo = {};
        var x = document.location.search.substring(1).split('&');
        for (var i in x) { var z = x[i].split('=',2); pdfInfo[z[0]] = unescape(z[1]); }
        function getPdfInfo() {
            var page = pdfInfo.page || 1;
            var pageCount = pdfInfo.topage || 1;
            document.getElementById('pdfkit_page_current').textContent = page;
            document.getElementById('pdfkit_page_count').textContent = pageCount;
        }
    </script>
    <style type="text/css">
        .legal-info #description {
            font-size: 4.5pt;
            margin-left: 10%;
            margin-top:-6px;
            float: left;
        }
        .legal-info #page {
            font-size: 7pt;
            margin-top:-10px;            
            float: right;
        }

    </style>
</head>
<body onload="getPdfInfo()">
    <!-- <img src="/var/sites/mysite/htdocs/images/logo.jpg" /> -->
    <section class="legal-info">
        <!--
        <p>Sultan Telecom SL. Calle Alfonso G&oacute;mez, 30, 4ª Planta 28037. Madrid, Espa&ntilde;a, CIF B-86484532. Registro Mercantil de Madrid, Tomo 30002, folio 150, inscripci&oacute;n 1, Hoja M-539974</p>
        -->
        <p id="page">Page <span id="pdfkit_page_current"></span> Of <span id="pdfkit_page_count"></span></p>
        <p id="description">{{data_bill.issuing_company_description}}</p>
    </section>
</body>
</html>
